@@ -1,8 +1,11 @@
+from typing import Optional, Dict
+
 import aiohttp
+
 from .model import Response
 
 
-async def get_json(url: str, params: dict | None = None, headers: dict | None = None) -> Response:
+async def get_json(url: str, params: Optional[Dict] = None, headers: Optional[Dict] = None) -> Response:
     async with aiohttp.ClientSession(headers=headers) as session:
         async with session.get(url, params=params) as response:
             response_json = await response.json()
@@ -11,7 +14,7 @@ async def get_json(url: str, params: dict | None = None, headers: dict | None =
             return Response(error=response_json, success=False)
 
 
-async def post_json(url: str, params: dict | None = None, headers: dict | None = None) -> Response:
+async def post_json(url: str, params: Optional[Dict] = None, headers: Optional[Dict] = None) -> Response:
     async with aiohttp.ClientSession(headers=headers) as session:
         async with session.post(url, params=params) as response:
             response_json = await response.json()
@@ -20,7 +23,7 @@ async def post_json(url: str, params: dict | None = None, headers: dict | None =
             return Response(error=response_json, success=False)
 
 
-async def get_bytes(url: str, params: dict | None = None, headers: dict | None = None) -> Response:
+async def get_bytes(url: str, params: Optional[Dict] = None, headers: Optional[Dict] = None) -> Response:
     async with aiohttp.ClientSession(headers=headers) as session:
         async with session.get(url, params=params) as response:
             response_data = await response.read()
