@@ -1,4 +1,4 @@
-from typing import TypeVar, List, Optional
+from typing import TypeVar, List, Optional, Dict, Generic, Union
 
 from pydantic import BaseModel, Field
 
@@ -6,38 +6,38 @@ DataT = TypeVar('DataT')
 
 
 class FastAPIErrorDetail(BaseModel):
-    loc: list[str]
+    loc: List[str]
     message: str = Field(alias='msg')
     type: str
 
 
 class FastApiErrorResponse(BaseModel):
-    detail: FastAPIErrorDetail | str
+    detail: Union[FastAPIErrorDetail, str]
 
 
 class APIErrorResponse(BaseModel):
     error_code: int
     detail: str
-    queue_position: int | None = None
+    queue_position: Optional[int] = None
 
 
-class Response(BaseModel):
-    data: DataT | None
-    error: APIErrorResponse | FastApiErrorResponse | None = None
+class Response(BaseModel, Generic[DataT]):
+    data: Optional[DataT] = None
+    error: Optional[Union[FastApiErrorResponse, APIErrorResponse]] = None
     success: bool = True
 
 
 class MembersAPIPlayer(BaseModel):
     username: str
-    id: int | None
+    id: Optional[int] = None
     is_online: bool = Field(alias='isOnline')
     is_leader: bool = Field(alias='isLeader')
     rank: int
-    rank_label: str | None = Field(alias='rankLabel')
-    ingame_id: int | None = Field(alias='ingameId')
-    ping: int | None
-    lvl: int | None
-    color: int | None
+    rank_label: Optional[str] = Field(None, alias='rankLabel')
+    ingame_id: Optional[int] = Field(None, alias='ingameId')
+    ping: Optional[int]
+    lvl: Optional[int]
+    color: Optional[int]
 
 
 class MembersAPIRecord(BaseModel):
@@ -49,11 +49,11 @@ class MembersAPIRecord(BaseModel):
 class MembersAPIResponse(BaseModel):
     server_label: str = Field(alias='serverName')
     fraction_label: str = Field(alias='fractionLabel')
-    players: list[MembersAPIPlayer]
+    players: List[MembersAPIPlayer]
     record: MembersAPIRecord
     total_players: int = Field(alias='totalPlayers')
     total_online: int = Field(alias='totalOnline')
-    leader_nickname: str | None = Field(alias='leaderNick')
+    leader_nickname: Optional[str] = Field(None, alias='leaderNick')
     is_leader_online: bool = Field(alias='isLeaderOnline')
     online_updated_at: int = Field(alias='onlineUpdatedAt')
     members_updated_at: int = Field(alias='membersUpdatedAt')
@@ -76,29 +76,29 @@ class CreatedFindTaskAPIResponse(BaseModel):
 
 
 class PlayerInfoAPIResponse(BaseModel):
-    account_id: int | None = Field(alias='accountId')
-    player_id: int | None = Field(alias='playerId')
-    lvl: int | None
-    cash: int | None
-    bank: int | None
-    individual_account: int | None = Field(alias='individualAccount')
-    deposit: int | None
-    total_money: int | None = Field(alias='totalMoney')
-    is_online: bool = Field(alias='isOnline')
-    job_label: str | None = Field(alias='jobLabel')
-    job_id: int | None = Field(alias='jobId')
-    rank_number: int | None = Field(alias='rankNumber')
-    rank_label: str | None = Field(alias='rankLabel')
-    is_leader: bool = Field(alias='isLeader')
-    org_label: str = Field(alias='orgLabel')
-    org_id: int = Field(alias='orgId')
-    vip_lvl: int | None = Field(alias='vipLvl')
-    vip_label: str | None = Field(alias='vipLabel')
-    phone_number: int | None = Field(alias='phoneNumber')
-    updated_at: int = Field(alias='updatedAt')
-    player_nick: str = Field(alias='playerNick')
-    player_server: int = Field(alias='playerServer')
-    server_name: str = Field(alias='serverName')
+    account_id: Optional[int] = Field(None, alias='accountId')
+    player_id: Optional[int] = Field(None, alias='playerId')
+    lvl: Optional[int] = None
+    cash: Optional[int] = None
+    bank: Optional[int] = None
+    individual_account: Optional[int] = Field(None, alias='individualAccount')
+    deposit: Optional[int] = None
+    total_money: Optional[int] = Field(None, alias='totalMoney')
+    is_online: bool = Field(False, alias='isOnline')
+    job_label: Optional[str] = Field(None, alias='jobLabel')
+    job_id: Optional[int] = Field(None, alias='jobId')
+    rank_number: Optional[int] = Field(None, alias='rankNumber')
+    rank_label: Optional[str] = Field(None, alias='rankLabel')
+    is_leader: bool = Field(False, alias='isLeader')
+    org_label: str = Field('', alias='orgLabel')
+    org_id: int = Field(0, alias='orgId')
+    vip_lvl: Optional[int] = Field(None, alias='vipLvl')
+    vip_label: Optional[str] = Field(None, alias='vipLabel')
+    phone_number: Optional[int] = Field(None, alias='phoneNumber')
+    updated_at: int = Field(0, alias='updatedAt')
+    player_nick: str = Field('', alias='playerNick')
+    player_server: int = Field(0, alias='playerServer')
+    server_name: str = Field('', alias='serverName')
 
 
 class PlayerInfoNotFound(APIErrorResponse):
@@ -113,7 +113,7 @@ class RatingPlayerInfo(BaseModel):
 
 class RatingAPIResponse(BaseModel):
     server: str
-    players: list[RatingPlayerInfo]
+    players: List[RatingPlayerInfo]
 
 
 class IpAPIResponse(BaseModel):
@@ -126,8 +126,8 @@ class IpAPIResponse(BaseModel):
 
 class CheckRPUsernameName(BaseModel):
     rp: bool
-    graph: str | None
-    gpt_answer: str | None
+    graph: Optional[str] = None
+    gpt_answer: Optional[str] = None
 
 
 class CheckRPUsernameAPIResponse(BaseModel):
@@ -190,4 +190,17 @@ class OnlinePlayerInfo(BaseModel):
 
 
 class PlayerOnlineAPIResponse(BaseModel):
-    sessions: list[OnlinePlayerInfo]
+    sessions: List[OnlinePlayerInfo]
+
+
+class PlayerData(BaseModel):
+    ingame_id: Optional[int] = Field(None, alias='ingameId')
+    lvl: Optional[int] = None
+    ping: Optional[int] = None
+    color: Optional[int] = None
+
+
+class PlayersAPIResponse(BaseModel):
+    server_name: str = Field(alias='serverName')
+    updated_at: int = Field(alias='updatedAt')
+    data: Dict[str, Optional[PlayerData]]
